// This import applies a global reset to any page that imports this stylesheet.
@import blueprint/reset

// To configure blueprint, edit the partials/base.sass file.
@import partials/base

// Import all the default blueprint modules so that we can access their mixins.
@import blueprint

// Combine the partials into a single screen stylesheet.
@import partials/page
@import partials/form
@import partials/two_col

