description "Button Plugin"
stylesheet 'buttons.sass', :media => 'screen, projection'

image 'buttons/cross.png'
image 'buttons/key.png'
image 'buttons/tick.png'

help %Q{
To install the button plugin:
  compass init --using blueprint/buttons

The buttons.sass file is just a recommendation to show you how to use the button mixins.  
}

welcome_message %Q{
The buttons.sass file is just a recommendation to show you how to use the button mixins.  
}
