description "Icons for common types of links"

stylesheet "link_icons.sass", :media => 'screen, projection'

image 'link_icons/doc.png'
image 'link_icons/email.png'
image 'link_icons/external.png'
image 'link_icons/feed.png'
image 'link_icons/im.png'
image 'link_icons/pdf.png'
image 'link_icons/visited.png'
image 'link_icons/xls.png'

help %Q{
To install the link_icons plugin:
  compass init --using blueprint/link_icons

The link_icons.sass file is just a recommendation to show you how to use the link mixins.  
}

welcome_message %Q{
The link_icons.sass file is just a recommendation to show you how to use the link mixins.  
}
