@import blueprint

// To generate css equivalent to the blueprint css but with your configuration applied, uncomment:
// @include blueprint-print

//Recommended Blueprint configuration with scoping and semantic layout:
body.bp
  +blueprint-print(true)