@import "blueprint/colors";
@import "blueprint/grid";
@import "blueprint/typography";
@import "blueprint/utilities";
@import "blueprint/form";
@import "blueprint/interaction";
@import "blueprint/debug";
@import "blueprint/print";
@import "blueprint/ie";

// ### Usage examples:
//
// As a top-level mixin, apply to any page that includes the stylesheet:
// <pre class="source-code sass">
// +blueprint
// </pre>
//
// Scoped by a presentational class:
// <pre class="source-code sass">
// body.blueprint
//   +blueprint(true)
// </pre>
//
// Scoped by semantic selectors:
// <pre class="source-code sass">
// body#page-1, body#page-2, body.a-special-page-type
//   +blueprint(true)
// </pre>

@mixin blueprint($nested: false) {
  @include blueprint-typography($nested);
  @include blueprint-utilities;
  @include blueprint-grid;
  @include blueprint-debug;
  @include blueprint-interaction;
  @include blueprint-form;
}
