// Here is where you can define your constants for your application and to configure the blueprint framework.
// Feel free to delete these if you want keep the defaults:

$blueprint-grid-columns : 24
$blueprint-grid-width   : 30px
$blueprint-grid-margin  : 10px

// If you change your grid column dimensions
// you can make a new grid background image from the command line like this:
// compass grid-img 30+10x16
